local log = Winning_Log
local L = LibStub("AceLocale-3.0"):GetLocale("Winning")
local addon = Winning
local ui_tabs = {'RECORDS', 'STATS'}



function Winning_Toggle_UI()
    if Winning_UI:IsVisible() then
        Winning_UI:Hide()
    else
        Winning_UI:Show();
    end
end



-- Used by the reporting buttons at the top of the UI
function Winning_Report(channel)
    log("Reporting to channel: " .. channel)

    local ctx = addon:current_context()
    local icon = "{skull}"

    local time_ctx = "(unknown)"
    if ctx.time.context == addon.dal.ALL then
        time_ctx = "ALL TIME"
    elseif ctx.time.context == addon.dal.SEASON then
        time_ctx = "THIS SEASON"
    elseif ctx.time.context == addon.dal.SIX_HOURS then
        time_ctx = "LAST SIX HOURS"
    end

    local map_ctx = nil
    if ctx.map.value == 1 then
        map_ctx = "All BGs"
    else
        map_ctx = addon.map_items[ctx.map.value]
    end

    local wins, losses = addon.dal:win_loss()
    local win_loss_ratio = addon.dal:win_loss_ratio(wins, losses)
    SendChatMessage(format("%s %s: %s (%s:%s) -> WINNING %s", icon, map_ctx, time_ctx, wins, losses, win_loss_ratio), channel, nil, nil)
end


-- Used to show contents of a single tab.
function Winning_Show_Tab(tab_name)
    if tab_name == ui_tabs[1] then
        Winning_UI_Stats:Hide()
        Winning_UI_Records:Show()
    elseif tab_name == ui_tabs[2] then
        Winning_UI_Records:Hide()
        Winning_UI_Stats:Show()
    end
end


-- Called when the tabs at the bottom of the UI are clicked.
function Winning_Tab_Clicked(tab_name)
    log("Tab clicked: " .. tab_name)
    for i, tab in ipairs(ui_tabs) do
        if tab == tab_name then
            PanelTemplates_SetTab(Winning_UI, i)
            Winning_Show_Tab(tab_name)
        end
    end
end


-- Called when the minimap button is clicked.
function Winning_Minimap_Click(btn)
    log(format("Minimap clicked: %s", tostring(btn)))
	if btn == "LeftButton" or btn == nil then
        Winning_Toggle_UI()
	end
end



-- Handles setting up the type context dropdown.
function Winning_Type_DropDown_OnLoad(self, level)
    -- TODO: Pre-select based on addon.db.char.type_context_value
    for i, v in pairs(addon.type_context_items) do
        local info = UIDropDownMenu_CreateInfo()
        info.text = L[v]
        info.func = Winning_Type_DropDown_OnClick
        UIDropDownMenu_AddButton(info, level);
    end
end

function Winning_Type_DropDown_OnClick(self)
	UIDropDownMenu_SetSelectedID(Winning_Type_DropDown, self:GetID());
    local selectedId = Winning_Context_DropDown['selectedID']
    local ctx = addon.context_items[selectedId]
    addon.db.char.type_context_value = selectedId
    log("Type context selected: " .. tostring(ctx))
    addon:context_updated()
end


-- Handles setting up the time context dropdown.
function Winning_Context_DropDown_OnLoad(self, level)
    -- TODO: Pre-select based on addon.db.char.time_context_value
    for i, v in pairs(addon.context_items) do
        local info = UIDropDownMenu_CreateInfo()
        info.text = L[v]
        info.func = Winning_Context_DropDown_OnClick
        UIDropDownMenu_AddButton(info, level);
    end
end

function Winning_Context_DropDown_OnClick(self)
	UIDropDownMenu_SetSelectedID(Winning_Context_DropDown, self:GetID());
    local selectedId = Winning_Context_DropDown['selectedID']
    local ctx = addon.context_items[selectedId]
    addon.db.char.time_context_value = selectedId
    log("Time context selected: " .. tostring(ctx))
    addon:context_updated()
end


-- Handles setting up the maps dropdown.
function Winning_Map_DropDown_OnLoad(self, level)
    -- TODO: Pre-select based on addon.db.char.map_context_value
    for i, v in pairs(addon.map_items) do
        local info = UIDropDownMenu_CreateInfo()
        info.text = v
        info.value = i
        info.func = Winning_Map_DropDown_OnClick
        UIDropDownMenu_AddButton(info, level);
    end
end


function Winning_Map_DropDown_OnClick(self)
	UIDropDownMenu_SetSelectedID(Winning_Map_DropDown, self:GetID());
    local selectedId = Winning_Map_DropDown['selectedID']
    local ctx = addon.map_items[selectedId]
    addon.db.char.map_context_value = selectedId
    log("Map context selected: " .. tostring(ctx))
    addon:context_updated()
end


function Winning_BG_Button_OnClick(btn)
    PlaySound("igMainMenuOptionCheckBoxOn")
    log("Setting clicked map to: " .. btn.map_name)
    addon.stats_selected_map_name = btn.map_name
    Winning_UI_Stats_Maps_Details:Show()
    addon:updateStatsTab(addon.stats_selected_map_name)
end


function Winning_Graph_Context_DropDown_OnLoad(self, level)
    for i, v in ipairs(addon.stats_context_items) do
        local info = UIDropDownMenu_CreateInfo()
        info.text = L[v]
        info.func = Winning_Graph_Context_DropDown_OnClick
        UIDropDownMenu_AddButton(info, level);
    end
    UIDropDownMenu_SetSelectedID(self, addon.db.char.graph_context_value or 1)
end


function Winning_Graph_Context_DropDown_OnClick(self)
	UIDropDownMenu_SetSelectedID(Winning_Context_DropDown, self:GetID());
    local selectedId = Winning_Context_DropDown['selectedID']
    local ctx = addon.context_items[selectedId]
    addon.db.char.graph_context_value = selectedId
    log("Graph context selected: " .. tostring(ctx))
end
