local log = Winning_Log

-------------------------------------------------------------------------------
-- WinningWiper
--
-- Wipes data according to come context (ALL data, SEASON data, etc.)
-------------------------------------------------------------------------------

WinningWiper = {}
WinningWiper.__index = WinningWiper

WinningWiper.init = function(self, addon)
    local self = {}
    setmetatable(self, WinningWiper)

    self.addon = addon
    self.db = self.addon.db.char.all_records
    self.bg_db = self.addon.db.char.bg_records
    self.bg_db_data = self.addon.db.char.bg_db_data

    self.ALL = "ALL"
    self.MOCK = "MOCK"
    self.SEASON = "SEASON"
    self.PREVIOUS_SEASONS = "PREVIOUS_SEASONS"
    self._allowed_wipe_contexts = {
        [self.ALL] = self._wipe_all,
        [self.MOCK] = self._wipe_mock,
        [self.SEASON] = self._wipe_season,
        [self.PREVIOUS_SEASONS] = self._wipe_previous_seasons,
    }
    return self
end


--
-- Wipe bg record data according to a data context and a value.
--
WinningWiper.wipe = function(self, ctx, val)
    local wipe_ctx = self:_check_ctx(ctx)
    if wipe_ctx then
        return wipe_ctx(self, val)
    else
        -- what else to do here?
        return {}
    end
end


-- check wipe context
WinningWiper._check_ctx = function(self, ctx)
    local wipe_ctx = self._allowed_wipe_contexts[ctx]
    if wipe_ctx then
        log("Using wipe context: " .. ctx)
        return wipe_ctx
    else
        log(format("Unknown data context: %s", ctx))
    end
end


-- Wipe everything and start fresh.
WinningWiper._wipe_all = function(self, val)
    self:wipe_db()
    self:wipe_bg_db()
    self:wipe_bg_db_data()
end


WinningWiper.wipe_db = function(self)
    local counter = 0
    for i, v in pairs(self.db) do
        self.db[i] = nil
        counter = counter + 1
    end
    log(format("Wiped %d records.", counter))
end


WinningWiper.wipe_bg_db = function(self)
    local counter = 0
    for i, v in pairs(self.bg_db) do
        self.bg_db[i] = nil
        counter = counter + 1
    end
    log(format("Wiped %d bg records.", counter))
end


WinningWiper.wipe_bg_db_data = function(self)
    local counter = 0
    for i, v in pairs(self.bg_db_data) do
        self.bg_db_data[i] = nil
        counter = counter + 1
    end
    log(format("Wiped %d bg records.", counter))
end


WinningWiper._wipe_mock = function(self)
    local counter = 0
    for i, v in pairs(self.db) do
        -- TODO: figure out how to wipe non-player data.
        if v.PlayerName ~= "Morpork" then
            self.db[i] = nil
            counter = counter + 1
        end
    end
    log(format("Wiped %d records.", counter))
end


WinningWiper._wipe_season = function(self)
    local counter = 0
    for i, v in pairs(self.db) do
        -- TODO: specify season to wipe?
        if v.Season == 16 then
            self.db[i] = nil
            counter = counter + 1
        end
    end
    log(format("Wiped %d records.", counter))
end
